@@ -1,24 +1,5 @@
-/* Copyright_License {
-
-  XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2021 The XCSoar Project
-  A detailed list of copyright holders can be found in the file "AUTHORS".
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-}
-*/
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The XCSoar Project
 
 package org.xcsoar;
 
@@ -52,6 +33,14 @@ final class NativeSensorListener implements SensorListener {
   @Override
   public native void onAccelerationSensor1(double acceleration);
 
+  @Override
+  public native void onEngineSensors(boolean has_cht_temp,
+                                     int cht_temp,
+                                     boolean has_egt_temp,
+                                     int egt_temp,
+                                     boolean has_ignitions_per_second,
+                                     float ignitions_per_second);
+
   @Override
   public native void onAccelerationSensor(float ddx, float ddy, float ddz);
 
