@@ -27,6 +27,7 @@ import android.content.BroadcastReceiver;
 import android.content.ServiceConnection;
 import android.content.ComponentName;
 import android.content.pm.PackageManager;
+import android.content.res.Configuration;
 import android.util.Log;
 import android.provider.Settings;
 
@@ -79,6 +80,8 @@ public class XCSoar extends Activity {
       return;
     }
 
+    NativeView.initNative(Build.VERSION.SDK_INT);
+
     NetUtil.initialise(this);
 
     IOIOHelper.onCreateContext(this);
@@ -95,6 +98,8 @@ public class XCSoar extends Activity {
        WindowUtil.leaveFullScreenMode() to avoid clearing those */
     initialWindowFlags = window.getAttributes().flags;
 
+    submitConfiguration(getResources().getConfiguration());
+
     batteryReceiver = new BatteryReceiver();
     registerReceiver(batteryReceiver,
                      new IntentFilter(Intent.ACTION_BATTERY_CHANGED));
@@ -352,4 +357,14 @@ public class XCSoar extends Activity {
     } else
       return super.dispatchTouchEvent(ev);
   }
+
+  private void submitConfiguration(Configuration config) {
+    final boolean nightMode = (config.uiMode & Configuration.UI_MODE_NIGHT_MASK) == Configuration.UI_MODE_NIGHT_YES;
+    NativeView.onConfigurationChangedNative(nightMode);
+  }
+
+  @Override public void onConfigurationChanged(Configuration newConfig) {
+    super.onConfigurationChanged(newConfig);
+    submitConfiguration(newConfig);
+  }
 }
