@@ -58,7 +58,7 @@ public:
   CrossSectionRenderer(const CrossSectionLook &look,
                        const AirspaceLook &airspace_look,
                        const ChartLook &chart_look,
-                       const bool &_inverse);
+                       bool _inverse) noexcept;
 
   void ReadBlackboard(const MoreData &_gps_info,
                       const DerivedInfo &_calculated_info,
