@@ -1,24 +1,5 @@
-/* Copyright_License {
-
-  XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2022 The XCSoar Project
-  A detailed list of copyright holders can be found in the file "AUTHORS".
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-}
- */
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The XCSoar Project
 
 #include "AirspaceWarningManager.hpp"
 #include "Geo/GeoVector.hpp"
@@ -218,7 +199,7 @@ public:
     if (!airspace.IsActive())
       return; // ignore inactive airspaces completely
 
-    if (!warning_manager.GetConfig().IsClassEnabled(airspace.GetType()) ||
+    if (!warning_manager.GetConfig().IsClassEnabled(airspace.GetClass()) ||
         ExcludeAltitude(airspace))
       return;
 
@@ -403,7 +384,7 @@ AirspaceWarningManager::UpdateInside(const AircraftState& state,
     const AltitudeState &altitude = state;
     if (// ignore inactive airspaces
         !airspace->IsActive() ||
-        !config.IsClassEnabled(airspace->GetType()) ||
+        !config.IsClassEnabled(airspace->GetClass()) ||
         !airspace->Inside(altitude))
       continue;
 
@@ -466,7 +447,7 @@ AirspaceWarningManager::GetAckDay(const AbstractAirspace &airspace) const noexce
 bool
 AirspaceWarningManager::IsActive(const AbstractAirspace &airspace) const noexcept
 {
-  return airspace.IsActive() && config.IsClassEnabled(airspace.GetType()) &&
+  return airspace.IsActive() && config.IsClassEnabled(airspace.GetClass()) &&
     !GetAckDay(airspace);
 }
 
