@@ -482,7 +482,6 @@ private:
                             const FlatBoundingBox &bb_now,
                             const FlatBoundingBox &bb_last,
                             bool &transition_enter, bool &transition_exit,
-                            bool &last_started,
                             const bool is_start);
 
   bool CheckTransitionOptionalStart(const AircraftState &state_now,
@@ -490,8 +489,7 @@ private:
                                     const FlatBoundingBox& bb_now,
                                     const FlatBoundingBox& bb_last,
                                     bool &transition_enter,
-                                    bool &transition_exit,
-                                    bool &last_started);
+                                    bool &transition_exit);
 
   /**
    * @param waypoints Active waypoint database
@@ -615,28 +613,6 @@ public:
   [[gnu::pure]]
   bool HasTargets() const;
 
-  /**
-   * Find location of center of task (for rendering purposes)
-   *
-   * @return Location of center of task or GeoPoint::Invalid()
-   */
-  [[gnu::pure]]
-  GeoPoint GetTaskCenter() const noexcept {
-    assert(!IsEmpty());
-    return task_projection.GetCenter();
-  }
-
-  /**
-   * Find approximate radius of task from center to edge (for rendering purposes)
-   *
-   * @return Radius (m) from center to edge of task
-   */
-  [[gnu::pure]]
-  double GetTaskRadius() const noexcept {
-    assert(!IsEmpty());
-    return task_projection.ApproxRadius();
-  }
-
   /**
    * returns the index of the highest intermediate TP that has been entered.
    * if none have been entered, returns zero
