@@ -51,12 +51,12 @@ public:
    *
    * @return Partially initialised object
    */
-  SampledTaskPoint(const GeoPoint &location, const bool is_scored);
+  SampledTaskPoint(const GeoPoint &location, const bool is_scored) noexcept;
 
   /** Reset the task (as if never flown) */
-  void Reset();
+  void Reset() noexcept;
 
-  const GeoPoint &GetLocation() const {
+  const GeoPoint &GetLocation() const noexcept {
     return nominal_points.front().GetLocation();
   }
 
@@ -67,7 +67,7 @@ public:
    * @return Location of max distance node
    */
   [[gnu::pure]]
-  const GeoPoint &GetLocationMax() const {
+  const GeoPoint &GetLocationMax() const noexcept {
     assert(search_max.IsValid());
 
     return search_max.GetLocation();
@@ -79,14 +79,14 @@ public:
    *
    * @return Location of minimum distance node
    */
-  const GeoPoint &GetLocationMin() const {
+  const GeoPoint &GetLocationMin() const noexcept {
     assert(search_min.IsValid());
 
     return search_min.GetLocation();
   };
 
   [[gnu::pure]]
-  GeoPoint InterpolateLocationMinMax(double p) const {
+  GeoPoint InterpolateLocationMinMax(double p) const noexcept {
     return GetLocationMin().Interpolate(GetLocationMax(), p);
   }
 
@@ -94,7 +94,7 @@ public:
    * Construct boundary polygon from internal representation of observation zone.
    * Also updates projection.
    */
-  void UpdateOZ(const FlatProjection &projection, const OZBoundary &boundary);
+  void UpdateOZ(const FlatProjection &projection, const OZBoundary &boundary) noexcept;
 
 protected:
   /**
@@ -104,7 +104,7 @@ protected:
    * @return True if internal state changed
    */
   bool AddInsideSample(const AircraftState &state,
-                       const FlatProjection &projection);
+                       const FlatProjection &projection) noexcept;
 
 public:
   /**
@@ -114,7 +114,7 @@ public:
    * @return True if sample present
    */
   [[gnu::pure]]
-  bool HasSampled() const {
+  bool HasSampled() const noexcept {
     return !sampled_points.empty();
   }
 
@@ -124,14 +124,14 @@ public:
    * @return Vector of sample points representing a closed polygon
    */
   [[gnu::pure]]
-  const SearchPointVector &GetSampledPoints() const {
+  const SearchPointVector &GetSampledPoints() const noexcept {
     return sampled_points;
   }
 
   /**
    * Retrieve boundary points polygon
    */
-  const SearchPointVector &GetBoundaryPoints() const {
+  const SearchPointVector &GetBoundaryPoints() const noexcept {
     assert(!boundary_points.empty());
 
     return boundary_points;
@@ -141,16 +141,16 @@ public:
    * Return a #SearchPointVector that contains just the reference
    * point.
    */
-  const SearchPointVector &GetNominalPoints() const {
+  const SearchPointVector &GetNominalPoints() const noexcept {
     return nominal_points;
   }
 
-  bool IsBoundaryScored() const {
+  bool IsBoundaryScored() const noexcept {
     return boundary_scored;
   }
 
 protected:
-  void SetPast(bool _past) {
+  void SetPast(bool _past) noexcept {
     past = _past;
   }
 
@@ -160,14 +160,14 @@ protected:
    * last sample prior to crossing the start.
    */
   void ClearSampleAllButLast(const AircraftState &state,
-                             const FlatProjection &projection);
+                             const FlatProjection &projection) noexcept;
 
 private:
   /**
    * Re-project boundary and interior sample polygons.
    * Must be called if task_projection changes.
    */
-  void UpdateProjection(const FlatProjection &projection);
+  void UpdateProjection(const FlatProjection &projection) noexcept;
 
 public:
   /**
@@ -182,7 +182,7 @@ public:
    * @return a list of boundary points
    */
   [[gnu::pure]]
-  const SearchPointVector &GetSearchPoints() const;
+  const SearchPointVector &GetSearchPoints() const noexcept;
 
   /**
    * Set the location of the sample/boundary polygon node
@@ -190,7 +190,7 @@ public:
    *
    * @param locmax Location of max distance node
    */
-  void SetSearchMax(const SearchPoint &locmax) {
+  void SetSearchMax(const SearchPoint &locmax) noexcept {
     assert(locmax.IsValid());
 
     search_max = locmax;
@@ -202,7 +202,7 @@ public:
    *
    * @param locmin Location of min distance node
    */
-  void SetSearchMin(const SearchPoint &locmin) {
+  void SetSearchMin(const SearchPoint &locmin) noexcept {
     assert(locmin.IsValid());
 
     search_min = locmin;
