@@ -2,21 +2,22 @@
 // Copyright The XCSoar Project
 #include "ScoredTaskPoint.hpp"
 
-ScoredTaskPoint::ScoredTaskPoint(const GeoPoint &location, bool b_scored)
+ScoredTaskPoint::ScoredTaskPoint(const GeoPoint &location, bool b_scored) noexcept
   :SampledTaskPoint(location, b_scored)
 {
-  Reset();
+  entered_state.ResetTime();
+  exited_state.ResetTime();
 }
 
 bool 
 ScoredTaskPoint::TransitionEnter(const AircraftState &ref_now,
-                                 const AircraftState &ref_last)
+                                 const AircraftState &ref_last) noexcept
 {
   if (!CheckEnterTransition(ref_now, ref_last))
     return false;
 
   if (EntryPrecondition() && (!ScoreFirstEntry() || !HasEntered()))
-    state_entered = ref_now;
+    entered_state = ref_now;
 
   return true;
 }
@@ -24,23 +25,22 @@ ScoredTaskPoint::TransitionEnter(const AircraftState &ref_now,
 bool 
 ScoredTaskPoint::TransitionExit(const AircraftState &ref_now,
                                 const AircraftState &ref_last,
-                                const FlatProjection &projection)
+                                const FlatProjection &projection) noexcept
 {
   if (!CheckExitTransition(ref_now, ref_last))
     return false;
 
   if (ScoreLastExit()) {
     ClearSampleAllButLast(ref_last, projection);
-    state_entered = ref_last;
   }
 
-  has_exited = true;
+  exited_state = ref_last;
 
   return true;
 }
 
 const GeoPoint &
-ScoredTaskPoint::GetLocationScored() const
+ScoredTaskPoint::GetLocationScored() const noexcept
 {
   if (IsBoundaryScored() || !HasEntered())
     return GetLocationMin();
@@ -49,9 +49,9 @@ ScoredTaskPoint::GetLocationScored() const
 }
 
 void 
-ScoredTaskPoint::Reset()
+ScoredTaskPoint::Reset() noexcept
 {
   SampledTaskPoint::Reset();
-  state_entered.ResetTime();
-  has_exited = false;
+  entered_state.ResetTime();
+  exited_state.ResetTime();
 }
