@@ -2,7 +2,7 @@
 // Copyright The XCSoar Project
 
 #include "ChartProjection.hpp"
-#include "Engine/Task/Ordered/OrderedTask.hpp"
+#include "Geo/Flat/TaskProjection.hpp"
 #include "Engine/Task/Ordered/Points/OrderedTaskPoint.hpp"
 
 void
@@ -16,13 +16,6 @@ ChartProjection::Set(const PixelRect &rc,
   Set(rc, center, radius);
 }
 
-void
-ChartProjection::Set(const PixelRect &rc, const OrderedTask &task) noexcept
-{
-  const auto radius = std::max(double(10000), task.GetTaskRadius());
-  Set(rc, task.GetTaskCenter(), radius);
-}
-
 void
 ChartProjection::Set(const PixelRect &rc,
                      const OrderedTaskPoint &point) noexcept
